ZeroAvatar class

Inheritance

Constructors

ZeroAvatar.asset(String avatarAsset, {Key? key, AvatarSize size = AvatarSize.l, bool withBadge = false, ZeroAvatarStyle? style, Widget? badgeChild})
Create avatar from asset Default values: size = AvatarSize.l withBadge = false
const
ZeroAvatar.file(String avatarFile, {Key? key, AvatarSize size = AvatarSize.l, bool withBadge = false, ZeroAvatarStyle? style, Widget? badgeChild})
Create avatar from File Default values: size = AvatarSize.l withBadge = false
const
ZeroAvatar.initial(String name, {Key? key, AvatarSize size = AvatarSize.l, bool withBadge = false, ZeroAvatarStyle? style, Widget? badgeChild})
Create avatar from full name text that only shows its initial Default values: size = AvatarSize.l withBadge = false
const
ZeroAvatar.url(String avatarUrl, {Key? key, AvatarSize size = AvatarSize.l, bool withBadge = false, ZeroAvatarStyle? style, Widget? badgeChild})
Create avatar from URL Default values: size = AvatarSize.l withBadge = false
const

Properties

badgeChild → Widget?
Can be Text, Icon, etc.
final
fullName → String?
The user's full name text to get the initial from
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → AvatarSize
Size of avatar, ranging from AvatarSize.xxs to AvatarSize.xxl Diameter values: 16, 24, 32, 48, 64, 96, 128 Default value: AvatarSize.l
final
style → ZeroAvatarStyle?
Allow to custom style of this avatar
final
type → SourceType
From URL, file, or asset
final
url → String?
final
variant → AvatarVariant
Can be image or initial characters
final
withBadge → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
changeSize(AvatarSize size) → ZeroAvatar
Change the size of avatar Typically as the children of ZeroAvatarGroup
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited