UnderlineButtonGroup class

Inheritance

Constructors

UnderlineButtonGroup({Key? key, required List<Widget> children, required List<bool> selecteds, required dynamic onItemSelected(int), required Color fillColor, required Color selectedColor, required BorderRadius borderRadius, required Color selectedFillColor, required double bottomBorderWidth, bool isVertical = false, bool square = false, double? verticalPadding})
const

Properties

borderRadius → BorderRadius
final
bottomBorderWidth → double
final
children → List<Widget>
final
fillColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
isVertical → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemSelected → dynamic Function(int)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color
final
selectedFillColor → Color
final
selecteds → List<bool>
final
square → bool
final
verticalPadding → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited