ZeroButtonIcon class

Inheritance

Constructors

ZeroButtonIcon.disabled({Key? key, required Widget icon, ZeroButtonIconStyle? style, ZeroButtonSize size = ZeroButtonSize.medium, ZeroButtonRadiusType borderRadiusType = ZeroButtonRadiusType.rectangle})
Build disabled button
const
ZeroButtonIcon.primary({Key? key, required Widget icon, required VoidCallback? onPressed, ZeroButtonIconStyle? style, ZeroButtonSize size = ZeroButtonSize.medium, ZeroButtonRadiusType borderRadiusType = ZeroButtonRadiusType.rectangle})
Build button icon with primary style
const
ZeroButtonIcon.secondary({Key? key, required Widget icon, required VoidCallback? onPressed, ZeroButtonIconStyle? style, ZeroButtonSize size = ZeroButtonSize.medium, ZeroButtonRadiusType borderRadiusType = ZeroButtonRadiusType.rectangle})
Build button icon with secondary style
const

Properties

borderRadiusType → ZeroButtonRadiusType
Border radius of ZeroButtonIcon
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
The child icon of button
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback?
Callback when button tap/pressed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → ZeroButtonSize
Size of button
final
style → ZeroButtonIconStyle?
Allow to cutomize style by preferences
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited