ZeroChipFilled class

Inheritance

Constructors

ZeroChipFilled({Key? key, Widget? avatar, required String label, IconData? cancelIcon, bool disabled = false, VoidCallback? onTap, VoidCallback? onTapCancel, ZeroChipSize size = ZeroChipSize.small, ZeroChipFilledStyle? style})
const

Properties

avatar → Widget?
A widget to display prior to the chip's label.
final
cancelIcon → IconData?
The icon on the right side of the chip, usually functions to delete/cancel the chip
final
disabled → bool
Disabling the chip will turn off the onTap gesture and also change the color of the content to gray
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The primary text content of this chip
final
onTap → VoidCallback?
Called when tap chip body
final
onTapCancel → VoidCallback?
Called when tap cancel icon button
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → ZeroChipSize
Adjusting the size variations of the chips can be small and large
final
style → ZeroChipFilledStyle?
Allows to customize the style of the chip, and the style will override that of the global theme ZeroTheme.chipFilledStyle
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited