ZeroDropdownMenuEntry<T> class

Defines a CustomDropdownMenu menu button that represents one item view in the menu.

See also:

Constructors

ZeroDropdownMenuEntry({required T value, required String label, Widget? leadingIcon, Widget? trailingIcon, bool enabled = true, ZeroButtonStyle? style})
Creates an entry that is used with CustomDropdownMenu.dropdownMenuEntries.
const

Properties

enabled → bool
Whether the menu item is enabled or disabled.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
The label displayed in the center of the menu item.
final
leadingIcon → Widget?
An optional icon to display before the label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ZeroButtonStyle?
Customizes this menu item's appearance.
final
trailingIcon → Widget?
An optional icon to display after the label.
final
value → T
the value used to identify the entry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited