ZeroListTile class

Inheritance

Constructors

ZeroListTile({Key? key, required String title, String? subtitle, Widget? rightIcon, Widget? leftIcon, bool withDivider = false, bool disabled = false, bool selected = false, VoidCallback? onTap, ZeroListTileStyle? style, ZeroListTileSize size = ZeroListTileSize.large, List<ZeroListTileAction> startSlideActions = const [], List<ZeroListTileAction> endSlideActions = const []})
const

Properties

disabled → bool
final
endSlideActions → List<ZeroListTileAction>
Slidable actions when sliding to the left
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftIcon → Widget?
Widget to be displayed on the left of ZeroListTile content. This widget as a marker that describes the ZeroListTile
final
onTap → VoidCallback?
Callback when listTile is tapped, but if state disabled is true then onTap won't work
final
rightIcon → Widget?
The widget will be displayed to the right of the ZeroListTile content, or it can be called the action button of the ZeroListTile
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
Marks the ZeroListTile in the selected state
final
size → ZeroListTileSize
Custom size
final
startSlideActions → List<ZeroListTileAction>
Slidable actions when sliding to the right
final
style → ZeroListTileStyle?
This will allow custom styling still and throughout this widget, and by default/fallback from the global theme if not set
final
subtitle → String?
The secondary text to be displayed in the ZeroListTile
final
title → String
The main text to be displayed in the ZeroListTile
final
withDivider → bool
withDivider shows the border/divider under ZeroListTile.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited