ZeroListTileAction class

An action for ZeroListTile which can show an icon, a label, or both.

Inheritance

Constructors

ZeroListTileAction({Key? key, bool autoClose = _kAutoClose, int flex = _kFlex, IconData? icon, Color backgroundColor = _kBackgroundColor, BorderRadius borderRadius = BorderRadius.zero, Color? foregroundColor, required String? label, SlidableActionCallback? onPressed, EdgeInsets? padding, double spacing = 4})
Creates a ZeroListTileAction.
const

Properties

autoClose → bool
Whether the enclosing Slidable will be closed after onPressed occurred.
finalinherited
backgroundColor → Color
The background color of this action.
finalinherited
borderRadius → BorderRadius
Padding of the OutlinedButton
finalinherited
flex → int
The flex factor to use for this child.
finalinherited
foregroundColor → Color?
The foreground color of this action.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
An icon to display above the label.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
A label to display below the icon.
finalinherited
onPressed → SlidableActionCallback?
Called when the action is tapped or otherwise activated.
finalinherited
padding → EdgeInsets?
Padding of the OutlinedButton
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
The space between icon and label if both set.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited