ZeroAppBar class

Inheritance
Implemented types

Constructors

ZeroAppBar({Key? key, ZeroAppBarSize size = ZeroAppBarSize.small, bool automaticallyImplyLeading = true, Widget? title, Widget? leading, List<Widget>? actions, PreferredSizeWidget? bottom, ZeroAppBarStyle? style})

Properties

actions → List<Widget>?
A list of Widgets to display in a row after the title widget.
final
automaticallyImplyLeading → bool
Controls whether we should try to imply the leading widget if null.
final
bottom → PreferredSizeWidget?
This widget appears across the bottom of the app bar. Typically a TabBar. Only widgets that implement PreferredSizeWidget can be used at the bottom of an app bar.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A widget to display before the toolbar's title.
final
preferredSize → Size
A size whose height is the sum of toolbarHeight and the bottom widget's preferred height.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → ZeroAppBarSize
Size of ZeroAppBar
final
style → ZeroAppBarStyle?
Allow to customize style for this ZeroAppBar
final
title → Widget?
The primary widget displayed in the app bar. Typically a Text widget that contains a description of the current contents of the app.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited