ZeroSkeletonListTile class

Inheritance

Constructors

ZeroSkeletonListTile({Key? key, bool hasLeading = true, SkeletonAvatarStyle? leadingStyle, SkeletonLineStyle? titleStyle = const SkeletonLineStyle(padding: EdgeInsets.all(0), height: 22), SkeletonLineStyle? subtitleStyle = const SkeletonLineStyle(height: 16, padding: EdgeInsetsDirectional.only(end: 32)), bool hasSubtitle = false, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(vertical: 8), double? contentSpacing = 8, double? verticalSpacing = 8, Widget? trailing})

Properties

child → Widget
finalinherited
contentSpacing → double?
final
hashCode → int
The hash code for this object.
no setterinherited
hasLeading → bool
final
hasSubtitle → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingStyle → SkeletonAvatarStyle?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleStyle → SkeletonLineStyle?
final
titleStyle → SkeletonLineStyle?
final
trailing → Widget?
final
verticalSpacing → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited