hide method
void
hide()
hide hides the snackbar by removing the overlay entry.
Implementation
void hide() {
_overlayEntry?.remove();
_overlayEntry = null;
}
hide hides the snackbar by removing the overlay entry.
void hide() {
_overlayEntry?.remove();
_overlayEntry = null;
}