ZeroStep class

Annotations

Constructors

ZeroStep({required Widget title, Widget? subtitle, required Widget content, ZeroStepState state = ZeroStepState.indexed, Widget? customIcon, bool isActive = false, Widget? label, ZeroStepStyle? style})
Creates a step for a Stepper.
const

Properties

content → Widget
The content of the step that appears below the title and subtitle.
final
customIcon → Widget?
customizes the icon of the step when state is set to ZeroStepState.customIcon
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
Whether or not the step is active. The flag only influences styling.
final
label → Widget?
Only StepperType.horizontal, Optional widget that appears under the title. By default, uses the bodyLarge theme.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ZeroStepState
The state of the step which determines the styling of its components and whether steps are interactive.
final
style → ZeroStepStyle?
final
subtitle → Widget?
The subtitle of the step that appears below the title and has a smaller font size. It typically gives more details that complement the title.
final
title → Widget
The title of the step that typically describes it.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited