ZeroRangeValues class

Constructors

ZeroRangeValues(int start, int end)
const

Properties

end → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final

Methods

copyWith({int? start, int? end}) → ZeroRangeValues
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited