childPadding method
Returns the padding value of the child widget in the badge widget ZeroBadge
Implementation
EdgeInsetsGeometry childPadding() => const EdgeInsets.all(12);
Returns the padding value of the child widget in the badge widget ZeroBadge
EdgeInsetsGeometry childPadding() => const EdgeInsets.all(12);