ZeroAlertDialogStyle class

Mixed-in types

Constructors

ZeroAlertDialogStyle({TextStyle? titleTextStyle, TextStyle? contentTextStyle, Color? barrierColor, EdgeInsetsGeometry? actionsPadding, EdgeInsetsGeometry? titlePadding, EdgeInsetsGeometry? contentPadding, EdgeInsetsGeometry? iconPadding, double elevation = 4, Color? backgroundColor, Color? shadowColor, Color? iconColor, AlignmentGeometry? alignment, ShapeBorder? shape})
const

Properties

actionsPadding → EdgeInsetsGeometry?
final
alignment → AlignmentGeometry?
final
backgroundColor → Color?
final
barrierColor → Color?
final
contentPadding → EdgeInsetsGeometry?
final
contentTextStyle → TextStyle?
final
elevation → double
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
final
iconPadding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
shape → ShapeBorder?
final
titlePadding → EdgeInsetsGeometry?
final
titleTextStyle → TextStyle?
final

Methods

copyWith({TextStyle? titleTextStyle, TextStyle? contentTextStyle, Color? barrierColor, EdgeInsetsGeometry? actionsPadding, EdgeInsetsGeometry? titlePadding, EdgeInsetsGeometry? contentPadding, EdgeInsetsGeometry? iconPadding, double? elevation, Color? backgroundColor, Color? shadowColor, Color? iconColor, AlignmentGeometry? alignment, ShapeBorder? shape}) → ZeroAlertDialogStyle
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroAlertDialogStyle? style) → ZeroAlertDialogStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({TextStyle? titleTextStyle, TextStyle? contentTextStyle, Color? barrierColor, EdgeInsetsGeometry? actionsPadding, EdgeInsetsGeometry? titlePadding, EdgeInsetsGeometry? contentPadding, EdgeInsetsGeometry? iconPadding, double elevation = 4, Color? backgroundColor, Color? shadowColor, Color? iconColor, AlignmentGeometry? alignment, ShapeBorder? shape}) → ZeroAlertDialogStyle
lerp(ZeroAlertDialogStyle? a, ZeroAlertDialogStyle? b, double t) → ZeroAlertDialogStyle