ZeroAppBarStyle class

Mixed-in types

Constructors

ZeroAppBarStyle({Color? backgroundColor, Color? foregroundColor, TextStyle? titleStyle, double? height, bool? centerTitle, Brightness? statusBarBrightness, double? elevation, Color? shadowColor, double? titleSpacing})
const

Properties

backgroundColor → Color?
The background coolor of ZeroAppBar
final
centerTitle → bool?
Set center title of ZeroAppBar
final
elevation → double?
The z-coordinate at which to place this app bar relative to its parent.
final
foregroundColor → Color?
The color of title and icons in ZeroAppBar
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Set height ZeroAppBar
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
The color of the shadow below the app bar.
final
statusBarBrightness → Brightness?
Status bar icon brightness
final
titleSpacing → double?
spacing around title content on the horizontal axis
final
titleStyle → TextStyle?
Set default style title of ZeroAppBar
final

Methods

copyWith({Color? backgroundColor, Color? foregroundColor, double? height, TextStyle? titleStyle, bool? centerTitle, Brightness? statusBarBrightness, double? elevation, Color? shadowColor, double? titleSpacing}) → ZeroAppBarStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroAppBarStyle? other) → ZeroAppBarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAppBarTheme() → AppBarTheme
Convert ZeroAppBarStyle to theme data divider material AppBarTheme
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, Color? foregroundColor, TextStyle? titleStyle, Brightness? statusBarBrightness, double? titleSpacing}) → ZeroAppBarStyle
A default value style of ZeroAppBarStyle
lerp(ZeroAppBarStyle? a, ZeroAppBarStyle? b, double t) → ZeroAppBarStyle