ZeroAvatarStyle class

Mixed-in types

Constructors

ZeroAvatarStyle({Color? backgroundColor, Color? badgeColor, Color? borderColor, Color? initialColor, TextStyle? initialStyle})
const

Properties

backgroundColor → Color?
backgroundColor of the avatar when no image
final
badgeColor → Color?
Background color of the badge when no child
final
borderColor → Color?
Border color of the avatar
final
hashCode → int
The hash code for this object.
no setterinherited
initialColor → Color?
text Color of the initials
final
initialStyle → TextStyle?
TextStyle of initial text
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? badgeColor, Color? borderColor, Color? initialColor, TextStyle? initialStyle}) → ZeroAvatarStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroAvatarStyle? other) → ZeroAvatarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, Color? badgeColor, Color? borderColor, Color? initialColor, TextStyle? initialStyle}) → ZeroAvatarStyle
A default value style of ZeroAvatarStyle
lerp(ZeroAvatarStyle? a, ZeroAvatarStyle? b, double t) → ZeroAvatarStyle