ZeroBottomSheetStyle class

Mixed-in types

Constructors

ZeroBottomSheetStyle({Color? backgroundColor, Color? handleColor, bool? useHandle, BorderRadiusGeometry? borderRadius, Color? barierColor, double? elevation})
const

Properties

backgroundColor → Color?
The background coolor of bottom sheet
final
barierColor → Color?
Border radius for the bottom sheet
final
borderRadius → BorderRadiusGeometry?
The Border radius of the bottom sheet
final
elevation → double?
final
handleColor → Color?
The color of the bottom sheet handle
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useHandle → bool?
Raise the bottom sheet handle, when useHandle is true
final

Methods

copyWith({Color? backgroundColor, Color? handleColor, Color? barierColor, BorderRadiusGeometry? borderRadius, bool? useHandle, double? elevation}) → ZeroBottomSheetStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroBottomSheetStyle? other) → ZeroBottomSheetStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBottomSheetTheme() → BottomSheetThemeData
Convert ZeroBottomSheetStyle to theme data bottom sheet material BottomSheetThemeData
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, Color? handleColor}) → ZeroBottomSheetStyle
A default value style of ZeroBottomSheetStyle
lerp(ZeroBottomSheetStyle? a, ZeroBottomSheetStyle? b, double t) → ZeroBottomSheetStyle