ZeroButtonGroupStyle class

A basic class for button group styles

Mixed-in types
Implementers

Constructors

ZeroButtonGroupStyle({Color? activeColor, Color? inactiveColor, Color? activeBorderColor, Color? inactiveBorderColor, TextStyle? activeTextStyle, TextStyle? inactiveTextStyle, EdgeInsetsGeometry? padding})
const

Properties

activeBorderColor → Color?
The button border color when it's active
final
activeColor → Color?
A background color when the button item is active. For type activeColor as foregroundColor
final
activeTextStyle → TextStyle?
Textstyle for text when the state button is active
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveBorderColor → Color?
The button border color when it;s state is inactive
final
inactiveColor → Color?
A background color when the button item is non active. For type inactiveColor as foregroundColor
final
inactiveTextStyle → TextStyle?
Textstyle for text when the state button is inactive
final
padding → EdgeInsetsGeometry?
Padding for each button item
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? activeColor, Color? inactiveColor, Color? activeBorderColor, Color? inactiveBorderColor, TextStyle? activeTextStyle, TextStyle? inactiveTextStyle, EdgeInsetsGeometry? padding}) → ZeroButtonGroupStyle
Copy the current instance with the new value given
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroButtonGroupStyle? other) → ZeroButtonGroupStyle
Merge two style of ZeroButtonGroupStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited