ZeroButtonGroupStyleSet class

Properties

filled → ZeroButtonGroupStyle?
A button group style for filled
final
hashCode → int
The hash code for this object.
no setterinherited
outlined → ZeroButtonGroupStyle?
A button group style for outlined
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → ZeroButtonGroupStyle?
A button group style for text
final
underline → ZeroButtonGroupStyle?
A button group style for underline
final

Methods

copyWith({ZeroButtonGroupStyle? filled, ZeroButtonGroupStyle? outlined, ZeroButtonGroupStyle? text, ZeroButtonGroupStyle? underline}) → ZeroButtonGroupStyleSet
Copy the current instance with the new value given
merge(ZeroButtonGroupStyleSet? other) → ZeroButtonGroupStyleSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({AccentColor? primaryColor, Color? textColor, Color? textActiveBackgroundColor}) → ZeroButtonGroupStyleSet
lerp(ZeroButtonGroupStyleSet? a, ZeroButtonGroupStyleSet? b, double t) → ZeroButtonGroupStyleSet