ZeroButtonGroupUnderlineStyle class

A button group style for a underline ZeroButtonGroup.

Inheritance

Constructors

ZeroButtonGroupUnderlineStyle({Color? activeColor, TextStyle? activeTextStyle, TextStyle? inactiveTextStyle, Color? underlineColor, EdgeInsetsGeometry? padding})
const

Properties

activeBorderColor → Color?
The button border color when it's active
finalinherited
activeColor → Color?
A background color when the button item is active. For type activeColor as foregroundColor
finalinherited
activeTextStyle → TextStyle?
Textstyle for text when the state button is active
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inactiveBorderColor → Color?
The button border color when it;s state is inactive
finalinherited
inactiveColor → Color?
A background color when the button item is non active. For type inactiveColor as foregroundColor
finalinherited
inactiveTextStyle → TextStyle?
Textstyle for text when the state button is inactive
finalinherited
padding → EdgeInsetsGeometry?
Padding for each button item
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? activeColor, Color? inactiveColor, Color? activeBorderColor, Color? inactiveBorderColor, TextStyle? activeTextStyle, TextStyle? inactiveTextStyle, EdgeInsetsGeometry? padding}) → ZeroButtonGroupStyle
Copy the current instance with the new value given
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(ZeroButtonGroupStyle? other) → ZeroButtonGroupStyle
Merge two style of ZeroButtonGroupStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({AccentColor? primaryColor, TextStyle? textStyle}) → ZeroButtonGroupUnderlineStyle