ZeroButtonIconStyle class

Mixed-in types

Constructors

ZeroButtonIconStyle({Color? color, Color? iconColor, double? iconSize})
const

Properties

color → Color?
Background color the button if primary style Foreground color the button if secondary style
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
Default icon color
final
iconSize → double?
Default icon size for larger size
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? color, Color? iconColor, double? iconSize}) → ZeroButtonIconStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroButtonIconStyle? other) → ZeroButtonIconStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? color, Color? iconColor}) → ZeroButtonIconStyle
A default value style of ZeroButtonIconStyle
lerp(ZeroButtonIconStyle? a, ZeroButtonIconStyle? b, double t) → ZeroButtonIconStyle