ZeroButtonIconStyleSet class

Mixed-in types

Constructors

ZeroButtonIconStyleSet({ZeroButtonIconStyle? primaryStyle, ZeroButtonIconStyle? secondaryStyle, double? largeSize, double? mediumSize, double? smallSize, Color? disabledColor})
const

Properties

disabledColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
largeSize → double?
final
mediumSize → double?
final
primaryStyle → ZeroButtonIconStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryStyle → ZeroButtonIconStyle?
final
smallSize → double?
final

Methods

copyWith({ZeroButtonIconStyle? primaryStyle, ZeroButtonIconStyle? secondaryStyle, double? largeSize, double? mediumSize, double? smallSize, Color? disabledColor}) → ZeroButtonIconStyleSet
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroButtonIconStyleSet? other) → ZeroButtonIconStyleSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited