ZeroButtonStyle class

ZeroButtonStyle is the class that will be used to style ZeroButton, ZeroButtonRightIcon, ZeroButtonLeftIcon, ZeroButtonRightLeftIcon, ZeroButtonIcon

Mixed-in types

Constructors

ZeroButtonStyle({Color? foregroundColor, Color? backgroundColor, Color? disabledForegroundColor, Color? disabledBackgroundColor, Color? shadowColor, Color? surfaceTintColor, double? elevation, TextStyle? textStyle, EdgeInsetsGeometry? padding, Size? minimumSize, Size? fixedSize, Size? maximumSize, BorderSide? side, OutlinedBorder? shape, VisualDensity? visualDensity, MaterialTapTargetSize? tapTargetSize, Duration? animationDuration, bool? enableFeedback, AlignmentGeometry? alignment, InteractiveInkFeatureFactory? splashFactory, Color? animatingColor})
const

Properties

alignment → AlignmentGeometry?
final
animatingColor → Color?
final
animationDuration → Duration?
final
backgroundColor → Color?
final
disabledBackgroundColor → Color?
final
disabledForegroundColor → Color?
final
elevation → double?
final
enableFeedback → bool?
final
fixedSize → Size?
final
foregroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
maximumSize → Size?
final
minimumSize → Size?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
final
shape → OutlinedBorder?
final
side → BorderSide?
final
splashFactory → InteractiveInkFeatureFactory?
final
surfaceTintColor → Color?
final
tapTargetSize → MaterialTapTargetSize?
final
textStyle → TextStyle?
final
visualDensity → VisualDensity?
final

Methods

copyWith({Color? foregroundColor, Color? backgroundColor, Color? disabledForegroundColor, Color? disabledBackgroundColor, Color? shadowColor, Color? surfaceTintColor, double? elevation, TextStyle? textStyle, EdgeInsetsGeometry? padding, Size? minimumSize, Size? fixedSize, Size? maximumSize, BorderSide? side, OutlinedBorder? shape, VisualDensity? visualDensity, MaterialTapTargetSize? tapTargetSize, Duration? animationDuration, bool? enableFeedback, AlignmentGeometry? alignment, InteractiveInkFeatureFactory? splashFactory, Color? animatingColor}) → ZeroButtonStyle
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroButtonStyle? other) → ZeroButtonStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toButtonStyle() → ButtonStyle
toButtonStyle is the function that will be used to convert ButtonStyle for button styling
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(ZeroButtonStyle? a, ZeroButtonStyle? b, double t) → ZeroButtonStyle
primaryStyle({ZeroSizeType? buttonSizeType, ZeroButtonRadiusType? buttonRadiusType, Color? foregroundColor, Color? backgroundColor, Color? disabledForegroundColor, Color? disabledBackgroundColor, Color? shadowColor, Color? surfaceTintColor, double? elevation, TextStyle? textStyle, EdgeInsetsGeometry? padding, Size? minimumSize, Size? fixedSize, Size? maximumSize, BorderSide? side, OutlinedBorder? shape, VisualDensity? visualDensity, MaterialTapTargetSize? tapTargetSize, Duration? animationDuration, bool? enableFeedback, AlignmentGeometry? alignment, InteractiveInkFeatureFactory? splashFactory, Color? animatingColor}) → ZeroButtonStyle
primaryStyle is the function that will be used to create ZeroButtonStyle with primary color
secondaryStyle({ZeroSizeType? buttonSizeType, ZeroButtonRadiusType? buttonRadiusType, Color? foregroundColor, Color? backgroundColor, Color? disabledForegroundColor, Color? disabledBackgroundColor, Color? shadowColor, Color? surfaceTintColor, double? elevation, TextStyle? textStyle, EdgeInsetsGeometry? padding, Size? minimumSize, Size? fixedSize, Size? maximumSize, BorderSide? side, OutlinedBorder? shape, VisualDensity? visualDensity, MaterialTapTargetSize? tapTargetSize, Duration? animationDuration, bool? enableFeedback, AlignmentGeometry? alignment, InteractiveInkFeatureFactory? splashFactory, Color? animatingColor}) → ZeroButtonStyle
secondaryStyle is the function that will be used to create ZeroButtonStyle with secondary color