ZeroCardOutlinedStyle class

a style for ZeroCard with border line and no shadow/elevation

Inheritance

Constructors

ZeroCardOutlinedStyle({Color? backgroundColor, BorderRadiusGeometry? borderRadius, BorderSide? side, EdgeInsetsGeometry? margin, bool? borderOnForeground})
const

Properties

backgroundColor → Color?
background color of the card
finalinherited
borderOnForeground → bool?
borderOnForeground is true if the border is to be painted on top of the card's child. If false, the border is painted behind the card's child.
finalinherited
borderRadius → BorderRadiusGeometry?
border radius of the card
finalinherited
elevation → double?
shadow elevation of the card
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry?
margin of the card
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
shadow color of the card
finalinherited
side → BorderSide?
border side of the card
finalinherited

Methods

copyWith({Color? backgroundColor, double? elevation, BorderRadiusGeometry? borderRadius, BorderSide? side, Color? shadowColor, EdgeInsetsGeometry? margin, bool? borderOnForeground}) → ZeroCardStyle
create a copy of ZeroCardStyle with some fields replaced with the new values
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(ZeroCardStyle? otherStyle) → ZeroCardStyle
merge two ZeroCardStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited