ZeroChipFilledStyle class

A style for widget ZeroChipFilled

Mixed-in types

Constructors

ZeroChipFilledStyle({Color? backgroundColor, TextStyle? textStyle, Color? iconColor})
const

Properties

backgroundColor → Color?
Background color of chip
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
Color for cancelIcon
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
Text style for label
final

Methods

copyWith({Color? backgroundColor, TextStyle? textStyle, Color? iconColor}) → ZeroChipFilledStyle
copyWith is a function that returns a new instance of ZeroChipFilledStyle with the properties of the current instance, except for the ones that are passed as arguments to the function
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroChipFilledStyle? other) → ZeroChipFilledStyle
Merge style from other ZeroChipFilledStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toChipThemeData() → ChipThemeData
Convert this style to ChipThemeData from material design
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, TextStyle? textStyle, Color? iconColor}) → ZeroChipFilledStyle
Get default value style of ZeroChipFilled
lerp(ZeroChipFilledStyle? a, ZeroChipFilledStyle? b, double t) → ZeroChipFilledStyle