ZeroCalendarPickerStyle class

Mixed-in types

Constructors

ZeroCalendarPickerStyle({TextStyle? headerTextStyle, TextStyle? dayTextStyle, Color? enabledDayColor, Color? disabledDayColor, Color? selectedDayColor, Color? selectedDayBackground, Color? highlightColor, Color? todayColor, Color? controlColor, Color? inactiveControlColor, ZeroListTileStyle? monthListTileStyle, ZeroListTileStyle? yearListTileStyle, Widget? monthLeftIcon, Widget? yearLeftIcon})
Creates a theme that can be used for ZeroCalendarPickerStyle or ZeroThemeData.datePickerStyle.calendar.
const

Properties

controlColor → Color?
The active color of the control to select year and month. If this is null the color defaults to ColorScheme.onSurface
final
dayTextStyle → TextStyle?
If this is null, the date picker defaults to the overall theme's ZeroTypography.labelSmall and with color ColorScheme.onSurface.
final
disabledDayColor → Color?
If this is null the color defaults to ColorScheme.onSurface.withOpacity(0.38);
final
enabledDayColor → Color?
If this is null the color defaults to ColorScheme.onSurface.withOpacity(0.87)
final
hashCode → int
The hash code for this object.
no setteroverride
headerTextStyle → TextStyle?
Used to configure the TextStyles for the text in the header. /// Used to configure the TextStyles for the text in the header.
final
highlightColor → Color?
If this is null the color defaults to ColorScheme.primary.withOpacity(0.12)
final
inactiveControlColor → Color?
The inactive color of the control to select year and month. If this is null the color defaults to context.theme.disabledColor
final
monthLeftIcon → Widget?
Widget to indicate that a particular month item is selected. It defaults to Icon(Icons.check)
final
monthListTileStyle → ZeroListTileStyle?
ZeroListTileStyle for month list. If null, it defaults to default styles of ZeroListTileStyle.fallback()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedDayBackground → Color?
If this is null the color defaults to ColorScheme.onPrimary
final
selectedDayColor → Color?
If this is null the color defaults to ColorScheme.onPrimary
final
todayColor → Color?
If this is null the color defaults to ColorScheme.primary
final
yearLeftIcon → Widget?
Widget to indicate that a particular year item is selected. It defaults to Icon(Icons.check)
final
yearListTileStyle → ZeroListTileStyle?
ZeroListTileStyle for month list. If null, it defaults to default styles of ZeroListTileStyle.fallback()
final

Methods

copyWith({TextStyle? headerTextStyle, TextStyle? dayTextStyle, Color? enabledDayColor, Color? disabledDayColor, Color? selectedDayColor, Color? selectedDayBackground, Color? highlightColor, Color? todayColor, Color? controlColor, Color? inactiveControlColor, ZeroListTileStyle? monthListTileStyle, ZeroListTileStyle? yearListTileStyle, Widget? monthLeftIcon, Widget? yearLeftIcon}) → ZeroCalendarPickerStyle
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroCalendarPickerStyle? other) → ZeroCalendarPickerStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(ZeroCalendarPickerStyle? a, ZeroCalendarPickerStyle? b, double t) → ZeroCalendarPickerStyle
Linearly interpolate between two date picker themes.