ZeroDatePickerStyle class

Defines the visual properties of the widget displayed with showZeroDatePicker.

Descendant widgets obtain the current ZeroDatePickerStyle object using context.theme.datePickerStyle. Instances of ZeroDatePickerStyle can be customized with ZeroDatePickerStyle.copyWith.

Typically a ZeroDatePickerStyle is specified as part of the overall ZeroTheme with ZeroThemeData.datePickerTheme.

All ZeroDatePickerStyle properties are null by default. When null, showZeroDatePicker will provide its own defaults.

TODO: separate styles between picker body and header

Mixed-in types

Constructors

ZeroDatePickerStyle({Color? headerBackgroundColor, Color? pickerBackgroundColor, TextStyle? dateTextStyle, Color? entryModeIconColor, TextStyle? helpTextStyle, ShapeBorder? shape, ZeroTextfieldStyle? textfieldStyle, double? elevation, EdgeInsets? insetPadding, ZeroCalendarPickerStyle? calendarStyle})
Creates a theme that can be used for ZeroDatePickerStyle or ZeroThemeData.datePickerStyle.
const

Properties

calendarStyle → ZeroCalendarPickerStyle?
Style for ZeroCalendarDatePicker
final
dateTextStyle → TextStyle?
final
elevation → double?
The elevation of the ZeroDatePickerDialog
final
entryModeIconColor → Color?
The color of the entry mode IconButton.
final
hashCode → int
The hash code for this object.
no setteroverride
headerBackgroundColor → Color?
The background color of the header part.
final
helpTextStyle → TextStyle?
Used to configure the TextStyles for the helper text in the header.
final
insetPadding → EdgeInsets?
of the dialog. This defines the minimum space between the screen's edges and the dialog.
final
pickerBackgroundColor → Color?
The background color of the picker part.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
The shape of the Dialog that the date picker is presented in.
final
textfieldStyle → ZeroTextfieldStyle?
The input decoration theme for the TextFields in the date picker.
final

Methods

copyWith({Color? headerBackgroundColor, Color? pickerBackgroundColor, Color? entryModeIconColor, TextStyle? dateTextStyle, TextStyle? helpTextStyle, ShapeBorder? shape, ZeroTextfieldStyle? textfieldStyle, double? elevation, EdgeInsets? insetPadding, ZeroCalendarPickerStyle? calendarStyle}) → ZeroDatePickerStyle
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroDatePickerStyle? other) → ZeroDatePickerStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fallback({Color? headerBackgroundColor, Color? pickerBackgroundColor, Color? entryModeIconColor, TextStyle? helpTextStyle, TextStyle? dateTextStyle, ShapeBorder? shape, ZeroTextfieldStyle? textfieldStyle, double? elevation, EdgeInsets? insetPadding, ZeroCalendarPickerStyle? calendarStyle}) → ZeroDatePickerStyle
lerp(ZeroDatePickerStyle? a, ZeroDatePickerStyle? b, double t) → ZeroDatePickerStyle
Linearly interpolate between two date picker themes.