ZeroDividerStyle class

Mixed-in types

Constructors

ZeroDividerStyle({Color? color, double? size, double? startInset, double? endInset})
const

Properties

color → Color?
Divider color
final
endInset → double?
Padding end
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
Height/width of divider or thickness
final
startInset → double?
Padding start
final

Methods

copyWith({Color? color, double? size, double? startInset, double? endInset}) → ZeroDividerStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroDividerStyle? other) → ZeroDividerStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toDividerTheme() → DividerThemeData
Convert ZeroDividerStyle to theme data divider material DividerThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? color}) → ZeroDividerStyle
A default value style of ZeroDividerStyle
lerp(ZeroDividerStyle? a, ZeroDividerStyle? b, double t) → ZeroDividerStyle