ZeroExpansionTileStyle class

Used with ZeroExpansionTileTheme to define default property values for descendant ZeroExpansionTile widgets.

Descendant widgets obtain the current ZeroExpansionTileStyle object using ZeroExpansionTileTheme.of(context). Instances of ZeroExpansionTileStyle can be customized with ZeroExpansionTileStyle.copyWith.

A ZeroExpansionTileStyle is often specified as part of the overall ZeroTheme with ThemeData.ZeroExpansionTileTheme.

All ZeroExpansionTileStyle properties are null by default. When a theme property is null, the ZeroExpansionTile will provide its own default based on the overall ZeroTheme's textTheme and colorScheme. See the individual ZeroExpansionTile properties for details.

See also:

  • ThemeData, which describes the overall theme information for the application.
  • ZeroExpansionTileTheme which overrides the default ZeroExpansionTileTheme of its ZeroExpansionTile descendants.
  • ThemeData.textTheme, text with a color that contrasts with the card and canvas colors.
  • ThemeData.colorScheme, the thirteen colors that most Material widget default colors are based on.
Mixed-in types
Annotations

Constructors

ZeroExpansionTileStyle({AccordionVariant? variant, Widget? leading, Widget? trailing, Color? backgroundColor, Color? collapsedBackgroundColor, Color? childrenBackgroundColor, EdgeInsetsGeometry? tilePadding, AlignmentGeometry? expandedAlignment, EdgeInsetsGeometry? childrenPadding, Color? iconColor, Color? collapsedIconColor, Color? textColor, Color? collapsedTextColor, ShapeBorder? shape, ShapeBorder? collapsedShape, Clip? clipBehavior, Color? titleColor, Color? collapsedTitleColor})
Creates a ZeroExpansionTileStyle.
ZeroExpansionTileStyle.filled({Widget? leading, Widget? trailing, Color? titleColor, Color? childrenBackgroundColor, Color? collapsedTitleColor, Color? iconColor, Color? collapsedIconColor, Color? textColor, Color? collapsedTextColor, ShapeBorder? shape, ShapeBorder? collapsedShape, EdgeInsetsGeometry? childrenPadding})
factory
ZeroExpansionTileStyle.underline({Widget? leading, Widget? trailing, Color? backgroundColor, Color? iconColor, Color? collapsedIconColor, Color? textColor, Color? collapsedTextColor, Color? lineColor, Color? collapsedLineColor, EdgeInsetsGeometry? childrenPadding})
factory

Properties

backgroundColor → Color?
Overrides the default value of ZeroExpansionTile.backgroundColor.
final
childrenBackgroundColor → Color?
Overrides the default value of ZeroExpansionTile.backgroundColor.
final
childrenPadding → EdgeInsetsGeometry?
Overrides the default value of ZeroExpansionTile.childrenPadding.
final
clipBehavior → Clip?
Overrides the default value of ZeroExpansionTile.clipBehavior.
final
collapsedBackgroundColor → Color?
Overrides the default value of ZeroExpansionTile.collapsedBackgroundColor.
final
collapsedIconColor → Color?
Overrides the default value of ZeroExpansionTile.collapsedIconColor.
final
collapsedShape → ShapeBorder?
Overrides the default value of ZeroExpansionTile.collapsedShape.
final
collapsedTextColor → Color?
Overrides the default value of ZeroExpansionTile.collapsedTextColor.
final
collapsedTitleColor → Color?
Background color of the title when collapsed
final
expandedAlignment → AlignmentGeometry?
Overrides the default value of ZeroExpansionTile.expandedAlignment.
final
hashCode → int
The hash code for this object.
no setteroverride
iconColor → Color?
Overrides the default value of ZeroExpansionTile.iconColor.
final
leading → Widget?
Overrides the default value of ZeroExpansionTile.leading.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
Overrides the default value of ZeroExpansionTile.shape.
final
textColor → Color?
Overrides the default value of ZeroExpansionTile.textColor.
final
tilePadding → EdgeInsetsGeometry?
Overrides the default value of ZeroExpansionTile.tilePadding.
final
titleColor → Color?
Background color of the title when expanded
final
trailing → Widget?
Overrides the default value of ZeroExpansionTile.trailing.
final
variant → AccordionVariant?
Variant of ZeroAccordion, values: AccordionVariant.underline, AccordionVariant.filled.
final

Methods

copyWith({AccordionVariant? variant, Widget? leading, Widget? trailing, Color? titleColor, Color? collapsedTitleColor, Color? backgroundColor, Color? collapsedBackgroundColor, Color? childrenBackgroundColor, EdgeInsetsGeometry? tilePadding, AlignmentGeometry? expandedAlignment, EdgeInsetsGeometry? childrenPadding, Color? iconColor, Color? collapsedIconColor, Color? textColor, Color? collapsedTextColor, ShapeBorder? shape, ShapeBorder? collapsedShape, Clip? clipBehavior}) → ZeroExpansionTileStyle
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
filled({Widget? leading, Widget? trailing, Color? titleColor, Color? collapsedTitleColor, Color? childrenBackgroundColor, Color? textColor, Color? collapsedTextColor, ShapeBorder? shape, ShapeBorder? collapsedShape}) → ZeroExpansionTileStyle
merge(ZeroExpansionTileStyle? other) → ZeroExpansionTileStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toExpansionTileThemeData() → ExpansionTileThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
underline({Widget? leading, Widget? trailing, Color? backgroundColor, Color? textColor, Color? collapsedTextColor, Color? lineColor, Color? collapsedLineColor, EdgeInsetsGeometry? childrenPadding}) → ZeroExpansionTileStyle

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fallback({Color? titleColor, Color? collapsedTitleColor, Color? backgroundColor, Color? collapsedBackgroundColor, Color? childrenBackgroundColor, Color? textColor, Color? collapsedTextColor, Color? iconColor, Color? collapsedIconColor}) → ZeroExpansionTileStyle
lerp(ZeroExpansionTileStyle? a, ZeroExpansionTileStyle? b, double t) → ZeroExpansionTileStyle?
Linearly interpolate between ZeroExpansionTileThemeData objects.