ZeroListTileStyle class

Mixed-in types

Constructors

ZeroListTileStyle({Color? selectedColor, Color? hoverColor, Color? backgroundColor, TextStyle? titleTextStyle, TextStyle? subTitleTextStyle, Color? dividerColor, TextStyle? smallTitleTextStyle, TextStyle? smallSubTitleTextStyle, EdgeInsets? contentPadding, EdgeInsets? smallContentPadding})
Creates a ZeroListTile style that defines the color and style parameters for descendant ZeroListTiles.
const

Properties

backgroundColor → Color?
Override from global theme of ZeroTheme.listTile backgroundColor
final
contentPadding → EdgeInsets?
Content padding
final
dividerColor → Color?
Override from global theme of ZeroTheme.listTile dividerColor
final
hashCode → int
The hash code for this object.
no setteroverride
hoverColor → Color?
Override from global theme of ZeroTheme.listTile hoverColor
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
Override from global theme of ZeroTheme.listTile selectedColor
final
smallContentPadding → EdgeInsets?
Content padding, while size is small
final
smallSubTitleTextStyle → TextStyle?
Override from global theme of ZeroTheme.listTile smallSubTitleTextStyle
final
smallTitleTextStyle → TextStyle?
Override from global theme of ZeroTheme.listTile smallTitleTextStyle
final
subTitleTextStyle → TextStyle?
Override from global theme of ZeroTheme.listTile subTitleTextStyle
final
titleTextStyle → TextStyle?
Override from global theme of ZeroTheme.listTile titleTextStyle
final

Methods

copyWith({Color? selectedColor, Color? hoverColor, Color? backgroundColor, TextStyle? titleTextStyle, TextStyle? subTitleTextStyle, TextStyle? smallTitleTextStyle, TextStyle? smallSubTitleTextStyle, Color? dividerColor, EdgeInsets? contentPadding, EdgeInsets? smallContentPadding}) → ZeroListTileStyle
It returns a new instance of the class with the given parameters.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroListTileStyle? other) → ZeroListTileStyle
If the value of the current instance is null, use the value of the other instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(covariant ZeroListTileStyle other) → bool
The equality operator.
override

Static Methods

fallback({Color? selectedColor, Color? hoverColor, Color? backgroundColor, Color? dividerColor, TextStyle? titleStyle, TextStyle? smallTitleStyle, TextStyle? subTitleStyle, TextStyle? smallSubTitleStyle}) → ZeroListTileStyle
Return default styles
lerp(ZeroListTileStyle? a, ZeroListTileStyle? b, double t) → ZeroListTileStyle