ZeroNavigationBarStyle class

Mixed-in types

Constructors

ZeroNavigationBarStyle({Color? backgroundColor, double? height, Color? indicatorColor, Color? unselectedColor, Color? selectedColor, Color? unselectedIconColor, Color? selectedIconColor, ZeroNavigationBarIndicatorType? indicatorType})
const

Properties

backgroundColor → Color?
Background of Navigation Bar, by default use white/black by theme
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Height of navigation bar
final
indicatorColor → Color?
Indicator background color when item is active
final
indicatorType → ZeroNavigationBarIndicatorType?
Type indicator on active
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
Label color when state is selected/active
final
selectedIconColor → Color?
Icon color when state is selected/active
final
unselectedColor → Color?
Label color when state is unselected/inactive
final
unselectedIconColor → Color?
Icon color when state is unselected/inactive
final

Methods

copyWith({Color? backgroundColor, Color? indicatorColor, Color? unselectedColor, Color? selectedColor, Color? unselectedIconColor, Color? selectedIconColor, double? height, ZeroNavigationBarIndicatorType? indicatorType}) → ZeroNavigationBarStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroNavigationBarStyle? other) → ZeroNavigationBarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toNavigationBarTheme() → NavigationBarThemeData
Convert ZeroNavigationBarStyle to theme data divider material NavigationBarThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, Color? indicatorColor, Color? unselectedColor, Color? selectedColor, Color? unselectedIconColor, Color? selectedIconColor}) → ZeroNavigationBarStyle
A default value style of ZeroNavigationBarStyle
lerp(ZeroNavigationBarStyle? a, ZeroNavigationBarStyle? b, double t) → ZeroNavigationBarStyle