ZeroNavigationDrawerStyle class

Mixed-in types

Constructors

ZeroNavigationDrawerStyle({Color? backgroundColor, double? width, ShapeBorder? shape, TextStyle? headerTitleStyle, TextStyle? sectionTitleStyle, bool separatorDrawer = true})
const

Properties

backgroundColor → Color?
Background of Drawer, by default use white/black by theme
final
hashCode → int
The hash code for this object.
no setterinherited
headerTitleStyle → TextStyle?
The text style of ZeroNavigationDrawerHeader
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionTitleStyle → TextStyle?
The title text style of ZeroNavigationDrawerSection
final
separatorDrawer → bool
Set enable/disable seperator each section
final
shape → ShapeBorder?
The shape of the drawer.
final
width → double?
Width of drawer
final

Methods

copyWith({Color? backgroundColor, TextStyle? headerTitleStyle, TextStyle? sectionTitleStyle, double? width, ShapeBorder? shape, bool? separatorDrawer}) → ZeroNavigationDrawerStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroNavigationDrawerStyle? other) → ZeroNavigationDrawerStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toNavigationDrawerTheme() → DrawerThemeData
Convert ZeroNavigationDrawerStyle to theme data divider material DrawerThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, TextStyle? headerTitleStyle, TextStyle? sectionTitleStyle}) → ZeroNavigationDrawerStyle
A default value style of ZeroNavigationDrawerStyle
lerp(ZeroNavigationDrawerStyle? a, ZeroNavigationDrawerStyle? b, double t) → ZeroNavigationDrawerStyle