ZeroNavigationRailStyle class

Mixed-in types

Constructors

ZeroNavigationRailStyle({Color? backgroundColor, double? width, Color? indicatorColor, Color? activeColor, Color? inactiveColor, TextStyle? labelStyle, TextStyle? activeLabelStyle, BorderRadius? indicatorBorderRadius})
const

Properties

activeColor → Color?
Color of icon when active
final
activeLabelStyle → TextStyle?
Text style of label segment NavigationRail when active
final
backgroundColor → Color?
A background color of navigation rail
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
Color of icon and label when inactive
final
indicatorBorderRadius → BorderRadius?
BorderRadius indicator when active
final
indicatorColor → Color?
Indicator Color when active
final
labelStyle → TextStyle?
Text style of label segment NavigationRail
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
Width of navigation rail
final

Methods

copyWith({Color? backgroundColor, double? width, Color? indicatorColor, Color? activeColor, Color? inactiveColor, TextStyle? labelStyle, TextStyle? activeLabelStyle, BorderRadius? indicatorBorderRadius}) → ZeroNavigationRailStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroNavigationRailStyle? other) → ZeroNavigationRailStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toNavigationRailTheme() → NavigationRailThemeData
Convert ZeroNavigationRailStyle to theme data navigation rail material NavigationRailThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgrondColor, Color? activeColor, Color? inactiveColor, Color? indicatorColor, TextStyle? labelStyle}) → ZeroNavigationRailStyle
A default value style of ZeroNavigationRailStyle
lerp(ZeroNavigationRailStyle? a, ZeroNavigationRailStyle? b, double t) → ZeroNavigationRailStyle