ZeroProgressStyle class

Mixed-in types

Constructors

ZeroProgressStyle({Color? backgroundColor, Color? valueColor, double? lineSize})
const

Properties

backgroundColor → Color?
Color of the track being filled by the progress indicator.
final
hashCode → int
The hash code for this object.
no setterinherited
lineSize → double?
The width of the line used to draw the progress indicator.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueColor → Color?
The progress indicator's color as an animated value.
final

Methods

copyWith({Color? valueColor, Color? backgroundColor, double? lineSize}) → ZeroProgressStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroProgressStyle? other) → ZeroProgressStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? valueColor, Color? backgroundColor, double? lineSize}) → ZeroProgressStyle
A default value style of ZeroProgressStyle
lerp(ZeroProgressStyle? a, ZeroProgressStyle? b, double t) → ZeroProgressStyle