ZeroRatingStyle class

Mixed-in types

Constructors

ZeroRatingStyle({Color? activeColor, Color? inactiveColor, double? spacing})
const

Properties

activeColor → Color?
Rating item color when the rating is selected
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
Rating item color when the rating is unselected
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double?
Spacing each reting item
final

Methods

copyWith({Color? activeColor, Color? inactiveColor, double? spacing}) → ZeroRatingStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroRatingStyle? other) → ZeroRatingStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? activeColor, Color? inactiveColor, double? spacing}) → ZeroRatingStyle
A default value style of ZeroRatingStyle
lerp(ZeroRatingStyle? a, ZeroRatingStyle? b, double t) → ZeroRatingStyle