SkeletonAvatarStyle class

Constructors

SkeletonAvatarStyle({double? width = 48, double? height = 48, EdgeInsetsGeometry padding = const EdgeInsets.all(0), bool? randomWidth, double? minWidth, double? maxWidth, bool? randomHeight, double? minHeight, double? maxHeight, BoxShape shape = BoxShape.rectangle, BorderRadiusGeometry? borderRadius = const BorderRadius.all(Radius.circular(4))})
Skeleton Style for Avatar
const

Properties

borderRadius → BorderRadiusGeometry?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
maxHeight → double?
final
maxWidth → double?
final
minHeight → double?
final
minWidth → double?
final
padding → EdgeInsetsGeometry
final
randomHeight → bool?
final
randomWidth → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → BoxShape
final
width → double?
final

Methods

copyWith({double? width, double? height, EdgeInsetsGeometry? padding, bool? randomWidth, double? minWidth, double? maxWidth, bool? randomHeight, double? minHeight, double? maxHeight, BoxShape? shape, BorderRadiusGeometry? borderRadius}) → SkeletonAvatarStyle
merge(SkeletonAvatarStyle? other) → SkeletonAvatarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited