SkeletonLineStyle class

Skeleton Style for line

Constructors

SkeletonLineStyle({double? width = double.infinity, double? height = 18, EdgeInsetsGeometry padding = const EdgeInsets.all(0), bool? randomLength, double? minLength, double? maxLength, BorderRadiusGeometry? borderRadius = const BorderRadius.all(Radius.circular(2)), AlignmentGeometry alignment = AlignmentDirectional.centerStart})
const

Properties

alignment → AlignmentGeometry
final
borderRadius → BorderRadiusGeometry?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
maxLength → double?
final
minLength → double?
final
padding → EdgeInsetsGeometry
final
randomLength → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

copyWith({double? width, double? height, EdgeInsetsGeometry? padding, bool? randomLength, double? minLength, double? maxLength, AlignmentGeometry? alignment, BorderRadiusGeometry? borderRadius}) → SkeletonLineStyle
merge(SkeletonLineStyle? other) → SkeletonLineStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited