SkeletonListTileStyle class

Skeleton Style for List Tile

Constructors

SkeletonListTileStyle({bool hasLeading = true, SkeletonAvatarStyle? leadingStyle, SkeletonLineStyle? titleStyle = const SkeletonLineStyle(padding: EdgeInsets.all(0), height: 22), SkeletonLineStyle? subtitleStyle = const SkeletonLineStyle(height: 16, padding: EdgeInsetsDirectional.only(end: 32)), bool hasSubtitle = false, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(vertical: 8), double? contentSpacing = 8, double? verticalSpacing = 8})
const

Properties

contentSpacing → double?
final
hashCode → int
The hash code for this object.
no setterinherited
hasLeading → bool
final
hasSubtitle → bool
final
leadingStyle → SkeletonAvatarStyle?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleStyle → SkeletonLineStyle?
final
titleStyle → SkeletonLineStyle?
final
verticalSpacing → double?
final

Methods

copyWith({bool? hasLeading, SkeletonAvatarStyle? leadingStyle, SkeletonLineStyle? titleStyle, bool? hasSubtitle, SkeletonLineStyle? subtitleStyle, EdgeInsetsGeometry? padding, double? contentSpacing, double? verticalSpacing}) → SkeletonListTileStyle
merge(SkeletonListTileStyle? other) → SkeletonListTileStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited