SkeletonParagraphStyle class

Skeleton Style for paragraph text

Constructors

SkeletonParagraphStyle({int lines = 3, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8, vertical: 8), double spacing = 12, SkeletonLineStyle lineStyle = const SkeletonLineStyle()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lines → int
final
lineStyle → SkeletonLineStyle
final
padding → EdgeInsetsGeometry
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
final

Methods

copyWith({int? lines, double? spacing, EdgeInsetsGeometry? padding, SkeletonLineStyle? lineStyle}) → SkeletonParagraphStyle
merge(SkeletonParagraphStyle? other) → SkeletonParagraphStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited