ZeroSkeletonStyleSet class

Constructors

ZeroSkeletonStyleSet({SkeletonAvatarStyle? avatar, SkeletonLineStyle? line, SkeletonListTileStyle? listTile, SkeletonParagraphStyle? paragraph})
const

Properties

avatar → SkeletonAvatarStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
line → SkeletonLineStyle?
final
listTile → SkeletonListTileStyle?
final
paragraph → SkeletonParagraphStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({SkeletonAvatarStyle? avatar, SkeletonLineStyle? line, SkeletonListTileStyle? listTile, SkeletonParagraphStyle? paragraph}) → ZeroSkeletonStyleSet
merge(ZeroSkeletonStyleSet? other) → ZeroSkeletonStyleSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited