ZeroSliderStyle class

Mixed-in types

Constructors

ZeroSliderStyle({Color? activeColor, Color? inactiveColor, Color? tickColor, Color? thumbColor, bool? tickBehavior, ZeroTooltipVariant? tooltipVariant, Color? tooltipColor})
const

Properties

activeColor → Color?
activeColor is the color of the active line of the slider
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
inactiveColor is the color of the inactive line of the slider when this value is null, the color will be activeColor with opacity 0.3
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbColor → Color?
thumbColor is the color of the thumb of the slider when this value is null, the color will be activeColor
final
tickBehavior → bool?
tickBehavior is a boolean that indicates if the slider will snap to the ticks
final
tickColor → Color?
tickColor is the color of the ticks the default color is ZeroColors.neutral8
final
tooltipColor → Color?
final
tooltipVariant → ZeroTooltipVariant?
tooltipVariant is the variant of the tooltip the default value is ZeroTooltipVariant.rounded the available variants are:
final

Methods

copyWith({Color? activeColor, Color? inactiveColor, Color? tickColor, ZeroTooltipVariant? tooltipVariant, Color? thumbColor, bool? tickBehavior, Color? tooltipColor}) → ZeroSliderStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroSliderStyle? other) → ZeroSliderStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toSliderTheme() → SliderThemeData
Convert ZeroSliderStyle to theme data divider material SliderThemeData
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? primaryColor, Color? thickColor, Color? thumbColor, bool? tickBehavior}) → ZeroSliderStyle
A default value style of ZeroSliderStyle
lerp(ZeroSliderStyle? a, ZeroSliderStyle? b, double t) → ZeroSliderStyle