ZeroSnackbarAlertStyle class

Constructors

ZeroSnackbarAlertStyle({TextStyle? titleStyle, BorderSide? border, BorderRadiusGeometry? borderRadius, Duration? duration, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? subtitleStyle, double? iconSize, Color? color, Color? defaultDangerColor, Color? defaultWarningColor, Color? defaultInfoColor, Color? defaultSuccessColor})
const

Properties

border → BorderSide?
border the border of snackbar
final
borderRadius → BorderRadiusGeometry?
The corners of this snackbar are rounded
final
color → Color?
Background color
final
defaultDangerColor → Color?
Default style when variant is danger
final
defaultInfoColor → Color?
Default style when variant is info
final
defaultSuccessColor → Color?
Default style when variant is success
final
defaultWarningColor → Color?
Default style when variant is warning
final
duration → Duration?
duration is the duration that the snackbar will be displayed, if duration is zero, the snackbar will not be dismissed automatically.
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double?
The icon size of snackbar alert type
final
margin → EdgeInsetsGeometry?
Margin of the snackbar
final
padding → EdgeInsetsGeometry?
Padding for the content of the snackbar
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleStyle → TextStyle?
subtitleStyle is the text style of the message.
final
titleStyle → TextStyle?
titleStyle is the title text style of the message.
final

Methods

copyWith({Duration? duration, TextStyle? titleStyle, TextStyle? subtitleStyle, BorderSide? border, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, BorderRadiusGeometry? borderRadius, double? iconSize, Color? color, Color? defaultDangerColor, Color? defaultWarningColor, Color? defaultInfoColor, Color? defaultSuccessColor}) → ZeroSnackbarAlertStyle
merge(ZeroSnackbarAlertStyle? other) → ZeroSnackbarAlertStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({TextStyle? subtitleStyle, TextStyle? titleStyle, Color? defaultDangerColor, Color? defaultWarningColor, Color? defaultInfoColor, Color? defaultSuccessColor}) → ZeroSnackbarAlertStyle
lerp(ZeroSnackbarAlertStyle? a, ZeroSnackbarAlertStyle? b, double t) → ZeroSnackbarAlertStyle