ZeroSnackbarStyle class

Mixed-in types

Constructors

ZeroSnackbarStyle({Color? backgroundColor, Duration? duration, TextStyle? textStyle, Widget? closeIcon, BorderSide? border, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, BorderRadiusGeometry? borderRadius, TextStyle? actionStyle, double? elevation})
const

Properties

actionStyle → TextStyle?
The text style of action
final
backgroundColor → Color?
backgroundColor is the background color of the snackbar.
final
border → BorderSide?
border the border of snackbar
final
borderRadius → BorderRadiusGeometry?
The corners of this snackbar are rounded
final
closeIcon → Widget?
closeIcon widget close snackbar icon
final
duration → Duration?
duration is the duration that the snackbar will be displayed, if duration is zero, the snackbar will not be dismissed automatically.
final
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry?
Margin of the snackbar
final
padding → EdgeInsetsGeometry?
Padding for the content of the snackbar
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
textStyle is the text style of the message.
final

Methods

copyWith({Color? backgroundColor, Duration? duration, TextStyle? textStyle, Widget? closeIcon, BorderSide? border, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, BorderRadiusGeometry? borderRadius, TextStyle? actionStyle, double? elevation}) → ZeroSnackbarStyle
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroSnackbarStyle? other) → ZeroSnackbarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, TextStyle? textStyle}) → ZeroSnackbarStyle
lerp(ZeroSnackbarStyle? a, ZeroSnackbarStyle? b, double t) → ZeroSnackbarStyle