ZeroStepStyle class

Mixed-in types

Constructors

ZeroStepStyle({Color? inactiveColor, Color? activeColor, Color? errorColor, Color? iconColor, TextStyle? indexTextStyle, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? contentTextStyle, TextStyle? labelTextStyle})
const

Properties

activeColor → Color?
final
contentTextStyle → TextStyle?
final
errorColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
final
inactiveColor → Color?
final
indexTextStyle → TextStyle?
final
labelTextStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleTextStyle → TextStyle?
final
titleTextStyle → TextStyle?
final

Methods

copyWith({Color? inactiveColor, Color? activeColor, Color? errorColor, Color? iconColor, TextStyle? indexTextStyle, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? contentTextStyle, TextStyle? labelTextStyle, double? stepSize}) → ZeroStepStyle
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroStepStyle? style) → ZeroStepStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? inactiveColor, Color? activeColor, Color? errorColor, Color? iconColor, TextStyle? indexTextStyle, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? contentTextStyle, TextStyle? labelTextStyle}) → ZeroStepStyle
lerp(ZeroStepStyle? a, ZeroStepStyle? b, double t) → ZeroStepStyle