ZeroSwitchStyle class

Mixed-in types

Constructors

ZeroSwitchStyle({Color? activeColor, Color? inactiveColor, Color? activeThumbColor, Color? inactiveThumbColor, double? thumbSize})
const

Properties

activeColor → Color?
Background color on active state
final
activeThumbColor → Color?
Thumb icon color when active
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveColor → Color?
Background color on inactive state
final
inactiveThumbColor → Color?
Thumb icon color when inactive
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbSize → double?
Size thumb
final

Methods

copyWith({Color? activeColor, Color? inactiveColor, Color? activeThumbColor, Color? inactiveThumbColor, double? thumbSize}) → ZeroSwitchStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroSwitchStyle? other) → ZeroSwitchStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? activeColor, Color? inactiveColor, Color? activeThumbColor, Color? inactiveThumbColor, double? thumbSize}) → ZeroSwitchStyle
A default value style of ZeroSwitchStyle
lerp(ZeroSwitchStyle? a, ZeroSwitchStyle? b, double t) → ZeroSwitchStyle