ZeroSwitchStyleSet class

Constructors

ZeroSwitchStyleSet({ZeroSwitchStyle? basic, ZeroSwitchStyle? android, ZeroSwitchStyle? iOS, Color? disabledColor})
const

Properties

android → ZeroSwitchStyle?
final
basic → ZeroSwitchStyle?
final
disabledColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
iOS → ZeroSwitchStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ZeroSwitchStyle? basic, ZeroSwitchStyle? android, ZeroSwitchStyle? iOS, Color? disabledColor}) → ZeroSwitchStyleSet
merge(ZeroSwitchStyleSet? other) → ZeroSwitchStyleSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({AccentColor? primaryColor, Color? inActiveColor, Color? inActiveIOSColor, Color? disabledColor}) → ZeroSwitchStyleSet
lerp(ZeroSwitchStyleSet? a, ZeroSwitchStyleSet? b, double t) → ZeroSwitchStyleSet