ZeroTabBarStyle class

Mixed-in types

Constructors

ZeroTabBarStyle({Color? backgroundColor, Color? activeColor, Color? inactiveColor, Color? indicatorColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? labelPadding, double? iconSize, TextStyle? labelStyle, bool isScrollable = false})
const

Properties

activeColor → Color?
Default label & icon color when tab item is active
final
backgroundColor → Color?
Background color of TabBar
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double?
Default icon size
final
inactiveColor → Color?
Default label & icon color when tab item is not active
final
indicatorColor → Color?
Indicator color tab active
final
isScrollable → bool
Tabbar style scrollable
final
labelPadding → EdgeInsetsGeometry?
The padding added to each of the tab labels.
final
labelStyle → TextStyle?
Text style for label
final
padding → EdgeInsetsGeometry?
Padding item of ZeroTab
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? backgroundColor, Color? activeColor, Color? inactiveColor, Color? indicatorColor, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? labelPadding, double? iconSize, TextStyle? labelStyle, bool? isScrollable}) → ZeroTabBarStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroTabBarStyle? other) → ZeroTabBarStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
toTabBarTheme() → TabBarTheme
Convert ZeroTabBarStyle to theme data divider material TabBarTheme

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? backgroundColor, Color? activeColor, Color? inactiveColor, Color? indicatorColor, EdgeInsetsGeometry? padding, double? iconSize, TextStyle? labelStyle}) → ZeroTabBarStyle
A default value style of ZeroTabBarStyle
lerp(ZeroTabBarStyle? a, ZeroTabBarStyle? b, double t) → ZeroTabBarStyle