ZeroTextfieldStyle class

Constructors

ZeroTextfieldStyle({required InputDecorationType inputDecorationType, required ZeroTextfieldSize textfieldSize, required Color focusedBorderColor, required Color focusedColor, BorderRadius? radius, Color? fillColor, bool enabled = true, bool error = false})
ZeroTextfieldStyle.fill({ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, Color? fillColor, Color? focusedColor})
factory
ZeroTextfieldStyle.outline({ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, BorderRadius? radius, Color? focusedColor})
factory
ZeroTextfieldStyle.rounded({ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, Color? focusedColor})
factory
ZeroTextfieldStyle.underline({ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, Color? focusedColor})
factory

Properties

alignLabelWithHint → bool
no setter
borderColor → Color
no setter
borderWidth → double
no setter
enabled → bool
final
error → bool
final
errorStyle → TextStyle
no setter
fillColor → Color?
final
filled → bool
no setter
floatingLabelBehavior → FloatingLabelBehavior
no setter
focusedBorderColor → Color
final
focusedColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
inputDecorationType → InputDecorationType
final
radius → BorderRadius?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textfieldSize → ZeroTextfieldSize
final

Methods

border(ZeroTextfieldSize sizeType) → InputBorder
borderRadius(ZeroTextfieldSize sizeType) → BorderRadius
copyWith({InputDecorationType? inputDecorationType, ZeroTextfieldSize? textfieldSize, bool? enabled, bool? error, Color? focusedBorderColor, Color? focusedColor, Color? fillColor}) → ZeroTextfieldStyle
disabledBorder(ZeroTextfieldSize sizeType) → InputBorder
errorBorder(ZeroTextfieldSize sizeType) → InputBorder
floatingLabelColor(bool error) → Color
floatingLabelStyle({required bool enabled, required bool error}) → TextStyle
focusedBorder(ZeroTextfieldSize sizeType) → InputBorder
getFillColor({required bool enabled, required bool error}) → Color
iconColor(bool error) → Color?
merge(ZeroTextfieldStyle? other) → ZeroTextfieldStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textStyle(bool enabled) → TextStyle
toInputDecoration() → InputDecoration
toInputDecorationTheme() → InputDecorationTheme
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited