ZeroTextfieldStyleSet class

A styles set of ZeroTextField for all variants

Constructors

ZeroTextfieldStyleSet.fallback({ZeroTextfieldStyle? outline, ZeroTextfieldStyle? rounded, ZeroTextfieldStyle? filled, ZeroTextfieldStyle? underline, required InputDecorationType defaultDecorationType, required ZeroTextfieldSize textfieldSize, required Color focusedBorderColor, required Color focusedColor})
factory
ZeroTextfieldStyleSet.fromDecorationType({ZeroTextfieldStyle? outline, ZeroTextfieldStyle? rounded, ZeroTextfieldStyle? filled, ZeroTextfieldStyle? underline, required InputDecorationType defaultDecorationType, ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, Color? focusedColor})
factory

Properties

defaultDecorationType → InputDecorationType
final
filled → ZeroTextfieldStyle
final
focusedBorderColor → Color?
final
focusedColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
mainStyle → ZeroTextfieldStyle
Main ZeroTextfieldStyle that would be applied globally
no setter
outline → ZeroTextfieldStyle
final
rounded → ZeroTextfieldStyle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textfieldSize → ZeroTextfieldSize
final
underline → ZeroTextfieldStyle
final

Methods

copyWith({ZeroTextfieldStyle? outline, ZeroTextfieldStyle? rounded, ZeroTextfieldStyle? filled, ZeroTextfieldStyle? underline, InputDecorationType? defaultDecorationType, ZeroTextfieldSize? textfieldSize, Color? focusedBorderColor, Color? focusedColor}) → ZeroTextfieldStyleSet
merge(ZeroTextfieldStyleSet? other) → ZeroTextfieldStyleSet
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited