HourMinuteControlStyle class

Mixed-in types

Constructors

HourMinuteControlStyle({Color? hourMinuteTextColor, Color? hourMinuteColor, TextStyle? hourMinuteTextStyle, ShapeBorder? hourMinuteShape})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
hourMinuteColor → Color?
The background color of the hour and minutes header segments.
final
hourMinuteShape → ShapeBorder?
The shape of the hour and minute controls that the time picker uses.
final
hourMinuteTextColor → Color?
The color of the header text that represents hours and minutes.
final
hourMinuteTextStyle → TextStyle?
Used to configure the TextStyles for the hour/minute controls.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? hourMinuteTextColor, Color? hourMinuteColor, TextStyle? hourMinuteTextStyle, ShapeBorder? hourMinuteShape}) → HourMinuteControlStyle
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(HourMinuteControlStyle? other) → HourMinuteControlStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fallback(Color? hourMinuteColor, Color? hourMinuteTextColor, TextStyle? hourMinuteTextStyle, ShapeBorder? hourMinuteShape) → HourMinuteControlStyle
lerp(HourMinuteControlStyle? a, HourMinuteControlStyle? b, double t) → HourMinuteControlStyle