ZeroTimePickerStyle class

Defines the visual properties of the widget displayed with showZeroTimePicker.

Descendant widgets obtain the current ZeroTimePickerStyle object using context.theme.timePickerStyle. Instances of ZeroTimePickerStyle can be customized with ZeroTimePickerStyle.copyWith.

Typically a ZeroTimePickerStyle is specified as part of the overall ZeroTheme with ZeroThemeData.timePickerTheme.

All ZeroTimePickerStyle properties are null by default. When null, showZeroTimePicker will provide its own defaults.

Mixed-in types

Constructors

ZeroTimePickerStyle({required HourMinuteControlStyle hourMinute, Color? backgroundColor, Color? dayPeriodTextColor, Color? dayPeriodColor, Color? dialHandColor, Color? dialBackgroundColor, Color? dialTextColor, Color? entryModeIconColor, TextStyle? dayPeriodTextStyle, TextStyle? helpTextStyle, ShapeBorder? shape, OutlinedBorder? dayPeriodShape, BorderSide? dayPeriodBorderSide, ZeroTextfieldStyle? textfieldStyle})
Creates a theme that can be used for ZeroTimePickerStyle or ZeroThemeData.timePickerStyle.
const

Properties

backgroundColor → Color?
The background color of a time picker.
final
dayPeriodBorderSide → BorderSide?
The color and weight of the day period's outline. If this is null, the time picker defaults to:
final
dayPeriodColor → Color?
The background color of the AM/PM toggle.
final
dayPeriodShape → OutlinedBorder?
The shape of the day period that the time picker uses. If this is null, the time picker defaults to:
final
dayPeriodTextColor → Color?
The color of the day period text that represents AM/PM.
final
dayPeriodTextStyle → TextStyle?
Used to configure the TextStyles for the day period control.
final
dialBackgroundColor → Color?
The background color of the time picker dial.
final
dialHandColor → Color?
The color of the time picker dial's hand.
final
dialTextColor → Color?
The color of the dial text that represents specific hours and minutes.
final
entryModeIconColor → Color?
The color of the entry mode IconButton.
final
hashCode → int
The hash code for this object.
no setteroverride
helpTextStyle → TextStyle?
Used to configure the TextStyles for the helper text in the header.
final
hourMinute → HourMinuteControlStyle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
The shape of the Dialog that the time picker is presented in.
final
textfieldStyle → ZeroTextfieldStyle?
The input decoration theme for the TextFields in the time picker.
final

Methods

copyWith({Color? backgroundColor, Color? dayPeriodTextColor, Color? dayPeriodColor, Color? dialHandColor, Color? dialBackgroundColor, Color? dialTextColor, Color? entryModeIconColor, TextStyle? dayPeriodTextStyle, TextStyle? helpTextStyle, ShapeBorder? shape, HourMinuteControlStyle? hourMinute, OutlinedBorder? dayPeriodShape, BorderSide? dayPeriodBorderSide, ZeroTextfieldStyle? textfieldStyle}) → ZeroTimePickerStyle
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroTimePickerStyle? other) → ZeroTimePickerStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fallback({required HourMinuteControlStyle hourMinute, Color? backgroundColor, BorderSide? dayPeriodBorderSide, Color? dayPeriodColor, OutlinedBorder? dayPeriodShape, Color? dayPeriodTextColor, TextStyle? dayPeriodTextStyle, Color? dialBackgroundColor, Color? dialHandColor, Color? dialTextColor, Color? entryModeIconColor, TextStyle? helpTextStyle, ShapeBorder? shape, ZeroTextfieldStyle? textfieldStyle}) → ZeroTimePickerStyle
lerp(ZeroTimePickerStyle? a, ZeroTimePickerStyle? b, double t) → ZeroTimePickerStyle
Linearly interpolate between two time picker themes.