ZeroTooltipStyle class

Mixed-in types

Constructors

ZeroTooltipStyle({Color? backgroundColor, Color? lightBackgroundColor, Color? darkBackgroundColor, TextStyle? textStyle, Color? borderColor, Duration? duration})
const

Properties

backgroundColor → Color?
Sets the background color of the tooltip
final
borderColor → Color?
The border color of tooltip
final
darkBackgroundColor → Color?
Automatically background color darkBackgroundColor when brightness is Brightness.dark
final
duration → Duration?
duration is the duration that the tooltip will show the default duration is 2 seconds
final
hashCode → int
The hash code for this object.
no setterinherited
lightBackgroundColor → Color?
Automatically background color lightBackgroundColor when brightness is Brightness.light
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
The text style label of the tooltip
final

Methods

copyWith({Color? backgroundColor, Color? lightBackgroundColor, Color? darkBackgroundColor, TextStyle? textStyle, Color? borderColor, Duration? duration}) → ZeroTooltipStyle
If the caller passes in a value for a parameter, use that value, otherwise use the value from this object.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ZeroTooltipStyle? other) → ZeroTooltipStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fallback({Color? lightColor, Color? darkColor, Color? borderColor}) → ZeroTooltipStyle
A default value style of ZeroTooltipStyle
lerp(ZeroTooltipStyle? a, ZeroTooltipStyle? b, double t) → ZeroTooltipStyle