ZeroBadgePosition enum
ZeroBadge component position options
This enum determine the position of the badge (top, bottom, right, left)
Values
- topLeft → const ZeroBadgePosition
-
Identify the badge with the top left
- topRight → const ZeroBadgePosition
-
Identify the badge with the top right
- bottomLeft → const ZeroBadgePosition
-
Identify the badge with the bottom left
- bottomRight → const ZeroBadgePosition
-
Identify the badge with the bottom right
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bottom(
double childPadding) → double? - Calculation of the bottom position on the badge
-
childPadding(
) → EdgeInsetsGeometry - Returns the padding value of the child widget in the badge widget ZeroBadge
-
left(
{required double childSize, required ZeroBadgeType type, required double childPadding}) → double? - Calculation of the left position on the badge
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
right(
{required double childSize, required ZeroBadgeType type, required double childPadding}) → double? - Calculation of the right position on the badge
-
top(
double childPadding) → double? - Calculation of the top position on the badge
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ZeroBadgePosition> - A constant List of the values in this enum, in order of their declaration.