lerp static method
It takes two ZeroTypography objects and a double value, and returns a new ZeroTypography
object that is a blend of the two input objects
Implementation
static ZeroTypography lerp(ZeroTypography? a, ZeroTypography? b, double t) {
return ZeroTypography.raw(
heading1: TextStyle.lerp(a?.heading1, b?.heading1, t),
heading2: TextStyle.lerp(a?.heading2, b?.heading2, t),
heading3: TextStyle.lerp(a?.heading3, b?.heading3, t),
heading4: TextStyle.lerp(a?.heading4, b?.heading4, t),
heading5: TextStyle.lerp(a?.heading5, b?.heading5, t),
heading6: TextStyle.lerp(a?.heading6, b?.heading6, t),
subtitle1: TextStyle.lerp(a?.subtitle1, b?.subtitle1, t),
subtitle2: TextStyle.lerp(a?.subtitle2, b?.subtitle2, t),
body1: TextStyle.lerp(a?.body1, b?.body1, t),
body2: TextStyle.lerp(a?.body2, b?.body2, t),
overline: TextStyle.lerp(a?.overline, b?.overline, t),
caption: TextStyle.lerp(a?.caption, b?.caption, t),
);
}